aboutsummaryrefslogtreecommitdiffstats
path: root/icefuzz/icecube.sh
diff options
context:
space:
mode:
Diffstat (limited to 'icefuzz/icecube.sh')
-rw-r--r--icefuzz/icecube.sh16
1 files changed, 15 insertions, 1 deletions
diff --git a/icefuzz/icecube.sh b/icefuzz/icecube.sh
index 2154b87..d098b66 100644
--- a/icefuzz/icecube.sh
+++ b/icefuzz/icecube.sh
@@ -10,7 +10,7 @@
# - <project_name>.pcf ## physical constraint file
#
# Running iCEcube2:
# - bash icecube.sh [-1k|-8k] <project_name> ## creates <project_name>.bin
#
#
#
@@ -41,6 +41,11 @@ if [ "$1" == "-8k" ]; then
shift
fi
+if [ "$1" == "-384" ]; then
+ ICEDEV=384-qn32
+ shift
+fi
+
if [ "$1" == "-ul1k" ]; then
ICEDEV=ul1k-cm36a
shift
@@ -92,6 +97,10 @@ case "${ICEDEV:-hx1k-tq144}" in
iCEPACKAGE="CB132"
iCE40DEV="iCE40HX8K"
;;
+ lp384-qn32)
+ iCEPACKAGE="QN32"
+ iCE40DEV="iCE40LP384"
+ ;;
lp1k-swg16tr)
iCEPACKAGE="SWG16TR"
iCE40DEV="iCE40LP1K"
@@ -177,6 +186,11 @@ case "$iCE40DEV" in
libfile="ice40HX8K.lib"
devfile="ICE40P08.dev"
;;
+ iCE40LP384)
+ icetech="SBTiCE40"
+ libfile="ice40LP384.lib"
+ devfile="ICE40P03.dev"
+ ;;
iCE40LP1K)
icetech="SBTiCE40"
libfile="ice40LP1K.lib"
@@ -10,7 +10,7 @@
#
# Running iCEcube2:
-# - bash icecube.sh [-1k|-8k] <project_name> ## creates <project_name>.bin
+# - bash icecube.sh [-1k|-8k|-384] <project_name> ## creates <project_name>.bin
#
#